==> dcoupon_sdk_flutter_package-2.0.0.tar.gz: lib/src/themes/light_theme.dart <==
import 'package:dcoupon_sdk_flutter_package/src/presentation/colors.dart';
import 'package:flutter/material.dart';

ThemeData dCouponLightWhite() {
  final baseTheme = ThemeData.light().copyWith(
    textTheme: ThemeData.light().textTheme.apply(
          fontFamily: 'Poppins',
        ),
    primaryTextTheme: ThemeData.light().primaryTextTheme.apply(
          fontFamily: 'Poppins',
          bodyColor: DCouponColors.dCouponPrimaryBlack,
          displayColor: Colors.black54,
        ),
    accentTextTheme: ThemeData.light().accentTextTheme.apply(
          fontFamily: 'Poppins',
        ),
  );

  return baseTheme.copyWith(
    accentColor: DCouponColors.dCouponPrimaryOrange,
    primaryColor: DCouponColors.dCouponPrimaryOrange,
    primaryColorDark: DCouponColors.dCouponWhite,
    scaffoldBackgroundColor: DCouponColors.dCouponWhite,
    colorScheme: baseTheme.colorScheme.copyWith(
      background: Colors.grey[300],
    ),
    snackBarTheme: baseTheme.snackBarTheme.copyWith(
      backgroundColor: DCouponColors.dCouponPrimaryOrange,
      contentTextStyle: baseTheme.textTheme.bodyText2
          .copyWith(color: DCouponColors.dCouponWhite),
    ),
    appBarTheme: baseTheme.appBarTheme.copyWith(
      color: DCouponColors.dCouponWhite,
      brightness: Brightness.light,
    ),
    buttonTheme: baseTheme.buttonTheme.copyWith(
      buttonColor: DCouponColors.dCouponPrimaryOrange,
      textTheme: ButtonTextTheme.primary,
    ),
    primaryIconTheme: baseTheme.primaryIconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    iconTheme: baseTheme.iconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    accentIconTheme: baseTheme.accentIconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    cursorColor: DCouponColors.dCouponPrimaryOrange,
    textSelectionHandleColor: DCouponColors.dCouponPrimaryOrange,
    bottomAppBarColor: DCouponColors.dCouponWhite,
    floatingActionButtonTheme: FloatingActionButtonThemeData(
        backgroundColor: DCouponColors.dCouponPrimaryOrange,
        foregroundColor: DCouponColors.dCouponWhite),
    cardColor: DCouponColors.dCouponWhite,
    toggleableActiveColor: DCouponColors.dCouponPrimaryOrange,
  );
}

==> dcoupon_sdk_flutter_package-4.0.1.tar.gz: lib/src/themes/light_theme.dart <==
import 'package:dcoupon_sdk_flutter_package/src/presentation/colors.dart';
import 'package:flutter/material.dart';

ThemeData dCouponLightWhite() {
  final baseTheme = ThemeData.light().copyWith(
    textTheme: ThemeData.light().textTheme.apply(
          fontFamily: 'Poppins',
        ),
    primaryTextTheme: ThemeData.light().primaryTextTheme.apply(
          fontFamily: 'Poppins',
          bodyColor: DCouponColors.dCouponPrimaryBlack,
          displayColor: Colors.black54,
        ),
    accentTextTheme: ThemeData.light().accentTextTheme.apply(
          fontFamily: 'Poppins',
        ),
  );

  return baseTheme.copyWith(
    accentColor: DCouponColors.dCouponPrimaryOrange,
    primaryColor: DCouponColors.dCouponPrimaryOrange,
    primaryColorDark: DCouponColors.dCouponWhite,
    scaffoldBackgroundColor: DCouponColors.dCouponWhite,
    colorScheme: baseTheme.colorScheme.copyWith(
      background: Colors.grey[300],
      primary: DCouponColors.dCouponPrimaryOrange,
    ),
    snackBarTheme: baseTheme.snackBarTheme.copyWith(
      backgroundColor: DCouponColors.dCouponPrimaryOrange,
      contentTextStyle: baseTheme.textTheme.bodyText2!
          .copyWith(color: DCouponColors.dCouponWhite),
    ),
    appBarTheme: baseTheme.appBarTheme.copyWith(
      color: DCouponColors.dCouponWhite,
      brightness: Brightness.light,
    ),
    buttonTheme: baseTheme.buttonTheme.copyWith(
      buttonColor: DCouponColors.dCouponPrimaryOrange,
      textTheme: ButtonTextTheme.primary,
    ),
    elevatedButtonTheme: ElevatedButtonThemeData(
      style: ElevatedButton.styleFrom(
        primary: DCouponColors.dCouponPrimaryOrange,
      ),
    ),
    primaryIconTheme: baseTheme.primaryIconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    iconTheme: baseTheme.iconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    accentIconTheme: baseTheme.accentIconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    textSelectionTheme: baseTheme.textSelectionTheme.copyWith(
      selectionHandleColor: DCouponColors.dCouponPrimaryOrange,
      cursorColor: DCouponColors.dCouponPrimaryOrange,
    ),
    bottomAppBarColor: DCouponColors.dCouponWhite,
    floatingActionButtonTheme: FloatingActionButtonThemeData(
        backgroundColor: DCouponColors.dCouponPrimaryOrange,
        foregroundColor: DCouponColors.dCouponWhite),
    cardColor: DCouponColors.dCouponWhite,
    toggleableActiveColor: DCouponColors.dCouponPrimaryOrange,
  );
}
